@@ -11,6 +11,9 @@ $ENV{LESSOPEN} = "|./lesspipe.sh %s";
 $ENV{PATH} .= ":."; # make sure we do find sxw2txt
 open F, "TESTCMDS" or die "Could not read TESTCMDS:$!\n";
 my $retcode = 0;
+my $duration = time();
+my $sumok = 0;
+my $sumnok = 0;
 while (<F>) {
   next if /^#/;
   next if /^\s*$/;
@@ -57,12 +60,16 @@ while (<F>) {
     $res =~ s/test/ok/ if $ok;
     $res =~ s/^\s+// if $ok;
     $res .= " ($lines trailing lines)" if $lines;
+    $sumok++;
   } else {
     $retcode++ if ! $ok and ! $ignore;
     $res = "NOT ok";
     $res .= " (ignored)" if $ignore;
+    $sumnok++;
   }
   printf "%-56s %s\n", $_, $res;
 }
 close F;
+$duration = time() - $duration;
+print "$sumok tests passed and $sumnok tests failed in $duration seconds\n";
 exit $retcode;
